summaryrefslogtreecommitdiffstats
path: root/source/cClientHandle.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--source/cClientHandle.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/source/cClientHandle.h b/source/cClientHandle.h
index 6e1079569..0b868420e 100644
--- a/source/cClientHandle.h
+++ b/source/cClientHandle.h
@@ -64,7 +64,7 @@ public:
E_PRIORITY_NORMAL
};
- static const int MAXBLOCKCHANGEINTERACTIONS = 10; // 5 didn't help, 10 seems to have done the trick
+ static const int MAXBLOCKCHANGEINTERACTIONS = 20; // 5 didn't help, 10 still doesn't work in Creative, 20 seems to have done the trick
static const int DEFAULT_VIEW_DISTANCE = 9; // The default ViewDistance (used when no value is set in Settings.ini)
static const int MAX_VIEW_DISTANCE = 10;